Changelog
=========

1.0.3 (2024-06-03)
------------------

- Register z3c.autoinclude.plugin entry point for Plone.
  This imports the package automatically on startup.
  This entry point is ignored when you don't use Plone.


1.0.2 (2024-05-31)
------------------

- Fix possible import error.


1.0.1 (2024-05-31)
------------------

- Fix several problems in initial release.


1.0.0 (2024-05-31)
------------------

- Initial release.
